####
Logo
####

The logo was a collaboration between Christina Lindberg, Sarv Parteek Singh, and Karl Gordon.
It uses python code for the extincion curve and AI for ideas (e.g., shield outline), with 
the final logo human created.

Details
=======

Extinction curve is for the Milky Way R(V) = 3.1 (G23, Gordon et al. 2023) and is log in the UV and 
linear in the MIR.  This allows the 2175 A carbonaceous bump and 10/20 micron silicate features 
to be seen.

Above the extinction curve, fewer stars are seen in the UV than in the MIR, 
symbolic of the higher extinction in the UV.

Shield evokes how dust shields us from photons (a nice positive way view).

Different Resolutions
=====================

Small
-----

.. image:: images/dust_extinction_logo_small.png
   :alt: dust_extinction logo low resolution

Medium
------

.. image:: images/dust_extinction_logo_med.png
   :alt: dust_extinction logo medium resolution

Full
----

.. image:: images/dust_extinction_logo.png
   :alt: dust_extinction logo full resolution

